Structs
- Cluster
Manager - Manages the background task that periodically attempts to renew leadership.
- Lock
Based Election - A standard implementation of leader election using a distributed lock.
Traits
- Leader
Election - Interface for components participating in cluster leader election.