pub struct ClusterManager {}Expand description
Manages the background task that periodically attempts to renew leadership.
Implementations
Sourceimpl ClusterManager
impl ClusterManager
Sourcepub fn start_election_loop<E: LeaderElection + 'static>(
election: Arc<E>,
interval: Duration,
) -> JoinHandle<()>
pub fn start_election_loop<E: LeaderElection + 'static>( election: Arc<E>, interval: Duration, ) -> JoinHandle<()>
Starts a background task that periodically polls the leader election