pub struct CompensationHandle { /* private fields */ }Expand description
Bus-insertable compensation hook handle used by runtime execution hooks.
Implementations
Sourceimpl CompensationHandle
impl CompensationHandle
Sourcepub fn from_hook<H>(hook: H) -> Selfwhere
H: CompensationHook + 'static,
pub fn from_hook<H>(hook: H) -> Selfwhere
H: CompensationHook + 'static,
Create a handle from a concrete compensation hook implementation.
Sourcepub fn from_arc(hook: Arc<dyn CompensationHook>) -> Self
pub fn from_arc(hook: Arc<dyn CompensationHook>) -> Self
Create a handle from an existing trait-object Arc.
Sourcepub fn hook(&self) -> Arc<dyn CompensationHook>
pub fn hook(&self) -> Arc<dyn CompensationHook>
Access the shared compensation hook.